import java.applet.Applet;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Frame;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.sql.Types;

import quadbase.reportdesigner.ReportAPI.DBInfo;
import quadbase.reportdesigner.ReportAPI.QbReport;
import quadbase.reportdesigner.ReportAPI.SubReport;
import quadbase.reportdesigner.ReportElements.SubReportObject;
import quadbase.reportdesigner.ReportViewer.Viewer;
import quadbase.reportdesigner.util.ColInfo;
import quadbase.reportdesigner.util.SimpleQueryFileInfo;
import quadbase.reportdesigner.util.SimpleQueryInParam;

public class ParameterizedSubReport extends Applet {
	static final long serialVersionUID = 1;

	public static void main(java.lang.String[] args) {

		try {

			ParameterizedSubReport doReport = new ParameterizedSubReport();
			Frame frame = new Frame();
			frame.setLayout(new BorderLayout());
			frame.add("Center", doReport.doParameterizedSubReport(frame));
			frame.setSize(900, 800);
			frame.addWindowListener(new WindowAdapter() {
				@Override
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});
			frame.setVisible(true);

		} catch (Exception ex) {

			ex.printStackTrace();

		}

	}

	@Override
	public void init() {

		setLayout(new BorderLayout());
		add("Center", doParameterizedSubReport(this));

	}

	Component doParameterizedSubReport(Object parent) {
		QbReport.setEspressManagerUsed(false);

		//		Begin Code : Creating the root Report
		DBInfo rootInfo = new DBInfo("jdbc:hsqldb:woodview",
				"org.hsqldb.jdbcDriver",
				"sa",
				"",
				"SELECT Customers.Company, Orders.OrderID, " +
						"Products.ProductName, Products.UnitPrice, " +
						"Order_Details.Quantity " +
						"FROM Order_Details, Products, Orders, Customers " +
						"WHERE (Orders.CustomerID = Customers.CustomerID) " +
						"AND (Order_Details.OrderID = Orders.OrderID) " +
						"AND (Products.ProductID = Order_Details.ProductID);");

		ColInfo rootColInfo[] = new ColInfo[5];
		rootColInfo[0] = new ColInfo(0);
		rootColInfo[0].setRowBreak(true);
		rootColInfo[1] = new ColInfo(1);
		rootColInfo[1].setRowBreak(true);
		rootColInfo[2] = new ColInfo(2);
		rootColInfo[2].setAggregation(false, ColInfo.NONE);
		rootColInfo[3] = new ColInfo(3);
		rootColInfo[3].setAggregation(false, ColInfo.AVG);
		rootColInfo[4] = new ColInfo(4);
		rootColInfo[4].setAggregation(false, ColInfo.SUM);

		QbReport rootReport = new QbReport(
				parent,
				QbReport.SUMMARY,
				rootInfo,
				rootColInfo,
				"ParameterizedSubReport.rpt");
		//		End Code : Creating the root Report

		int numberOfTableHeaderCells = rootReport.getTable().getHeader().getData().length;

		//		Transferring Table Header cells to Row Break Zero Header
		for (int i = 0; i < numberOfTableHeaderCells; i++)
		{

			rootReport.getTable().getRowBreakHeader(0)
					.addData(rootReport.getTable().getHeader().getData(i));
			rootReport.getTable().getRowBreakHeader(0).getData(i).setY(1);
		}

		//		Deleting Table Header cells
		for (int i = 0; i < numberOfTableHeaderCells; i++) {
			rootReport.getTable().getHeader().removeData(0);
		}

		//		Begin Code : Creating the SubReport
		//		SimpleQueryInParam(name of Parameter, String to be displayed, MapToColumn?, tableName, ColumnName, SQL Type, DefaultValue, value)
		SimpleQueryInParam inParam = new SimpleQueryInParam(
				"Company", "Please select", true, "Customers",
				"Company", Types.VARCHAR, "All Unfinished Furniture",
				"All Unfinished Furniture");
		SimpleQueryInParam[] paramSet = { inParam };

		SimpleQueryFileInfo subReportInfo = new SimpleQueryFileInfo(
				"jdbc:hsqldb:woodview",
				"org.hsqldb.jdbcDriver",
				"sa", "",
				"SELECT Customers.CustomerID, Customers.ContactName, " +
						"Customers.Address, Customers.City, " +
						"Customers.State, Customers.Zip " +
						"FROM Customers " +
						"WHERE (Customers.Company =:Company);");
		subReportInfo.setInParam(paramSet);

		//		Begin Code : Setting up Column Mapping
		ColInfo subReportColInfo[] = new ColInfo[6];
		for (int i = 0; i < subReportColInfo.length; i++) {
			subReportColInfo[i] = new ColInfo(i);
		}

		//		End Code : Setting up Column Mapping

		try {

			//			createSubReport(root report, report type, sub report data source, sub report column mapping, template)
			SubReportObject reportCell = SubReport.createSubReport(
					rootReport,
					QbReport.COLUMNAR,
					subReportInfo,
					subReportColInfo,
					null);
			((QbReport) reportCell.getSubReport()).applyTemplate(
					"ParameterizedSubReportSub.rpt", true);

			//			Get Parameter from root report column
			reportCell.setParameterMap(new String[] { rootReport.getTable().getColumn(0).getID() });

			//			Set SubReport cell's height and width
			reportCell.setWidth(7.2);
			reportCell.setResizeToFitContent(true);
			reportCell.setY(.3);
			reportCell.setX(0);

			//			Add SubReport to the Group Zero Header
			rootReport.getTable().getRowBreakHeader(0).addData(reportCell);

		} catch (Exception ex) {
			ex.printStackTrace();
		}
		//		End Code : Creating the sub report

		return (new Viewer().getComponent(rootReport));

	}

}